[pitivi] build: Update numpy and matplotlib



commit 769efd7a29f3345c0f438e989d6bb50f1d8b3812
Author: Alexandru Băluț <alexandru balut gmail com>
Date:   Sun Mar 5 15:21:15 2017 +0100

    build: Update numpy and matplotlib
    
    Reviewed-by: Thibault Saunier <tsaunier gnome org>
    Differential Revision: https://phabricator.freedesktop.org/D1700

 build/flatpak/pitivi.template.json |    4 ++--
 pitivi/timeline/elements.py        |    4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/build/flatpak/pitivi.template.json b/build/flatpak/pitivi.template.json
index ddd7c58..0d078d2 100644
--- a/build/flatpak/pitivi.template.json
+++ b/build/flatpak/pitivi.template.json
@@ -72,7 +72,7 @@
               "cflags": "-O0 -g  -L/usr/lib -Lbuild/temp.linux-x86_64-3.4 -I/usr/include 
-I/usr/include/python3.4m/",
               "env": {"ARCHFLAGS": "-arch x86_64"}
             },
-            "config-opts": ["--module=numpy==1.10.1"],
+            "config-opts": ["--module=numpy==1.12.1"],
             "sources": [
                 {
                     "type": "file",
@@ -114,7 +114,7 @@
             "build-options" : {
               "build-args": ["--share=network"]
             },
-            "config-opts": ["--module=matplotlib==1.5.1"],
+            "config-opts": ["--module=matplotlib==2.0.0"],
             "sources": [
                 {
                     "type": "file",
diff --git a/pitivi/timeline/elements.py b/pitivi/timeline/elements.py
index 9c66b17..83e9909 100644
--- a/pitivi/timeline/elements.py
+++ b/pitivi/timeline/elements.py
@@ -111,8 +111,8 @@ class KeyframeCurve(FigureCanvas, Loggable):
         self.__line_xs = []
         self.__line_ys = []
 
-        # axisbg to None for transparency
-        self.__ax = figure.add_axes([0, 0, 1, 1], axisbg='None')
+        # facecolor to None for transparency
+        self.__ax = figure.add_axes([0, 0, 1, 1], facecolor='None')
         # Clear the Axes object.
         self.__ax.cla()
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]